# vim: set ft=spec: -*- rpm-spec -*-
%define _unpackaged_files_terminate_build 1

%define ver_major 2.22

%def_enable debug

%def_with ldap
%def_enable hkp
%def_enable gedit
%def_enable nautilus
%def_enable gnome_keyring

%if_enabled hkp
%def_enable sharing
%endif

%def_disable epiphany
%def_enable dbus

%if_enabled dbus
# Problems with Gecko detection (epiphany build now with firefox gecko - must work)
#def_enable epiphany
%def_enable gedit
%endif

%def_enable libnotify
%def_enable ssh

Name: seahorse
Version: %ver_major.1
Release: alt1.qa1.M41.1

Summary: Seahorse is a GNOME frontend to GnuPG
License: %gpllgpl2plus
Group: Graphical desktop/GNOME
Url: http://www.gnome.org/projects/%name/
Packager: GNOME Maintainers Team <gnome at packages.altlinux.org>

Source: %gnome_ftp/%name/%ver_major/%name-%version.tar.bz2
Source2: seahorse-agent.sh

Requires: gnupg
Requires: lib%name = %version-%release
%{?_enable_ssh:Requires: openssh-clients}

BuildPreReq: rpm-build-gnome

# From configure.in
BuildPreReq: intltool >= 0.35
BuildPreReq: gnome-doc-utils >= 0.3.2
BuildPreReq: libgnome-devel >= 2.14
BuildPreReq: libgnomeui-devel
BuildPreReq: libgtk+2-devel >= 2.10.0
BuildPreReq: gnupg >= 1.2
BuildPreReq: libgpgme-devel >= 1.0.0
BuildPreReq: libgpg-error-devel
%{?_with_ldap:BuildPreReq: libldap-devel}
%{?_enable_hkp:BuildPreReq: libsoup-devel >= 2.3}
%if_enabled nautilus
BuildPreReq: libnautilus-devel >= 2.9.0
BuildPreReq: glib2-devel >= 2.10.0
%endif
%{?_enable_gnome_keyring:BuildPreReq: libgnome-keyring-devel}
%{?_enable_sharing:BuildPreReq: libavahi-glib-devel >= 0.6}
%if_enabled dbus
BuildPreReq: libdbus-glib-devel >= 0.35
%if_enabled epiphany
BuildPreReq: epiphany-devel >= 2.14.0
BuildPreReq: firefox-devel
BuildPreReq: libxml2-devel >= 2.6.0
BuildPreReq: glib2-devel >= 2.10.0
%endif
%{?_enable_gedit:BuildPreReq: gedit-devel >= 2.6}
BuildPreReq: libgnome-panel-devel >= 2.9.4
%endif
%{?_enable_libnotify:BuildPreReq: libnotify-devel >= 0.3}
%{?_enable_ssh:BuildPreReq: openssh openssh-clients}

BuildRequires: docbook-dtds gcc-c++ perl-XML-Parser python-modules-compiler
BuildRequires: libSM-devel rpm-build-licenses evolution-data-server-devel
BuildRequires: desktop-file-utils

%description
Seahorse is a graphical interface for managing and using encryption keys. 
Currently it supports PGP keys using for Gnu Privacy Guard. Its goal is to 
provide an easy to use Key Management Tool, along with an easy to use interface for encryption operations.

%package -n lib%name
Summary: Seahorse libraries
Group: Graphical desktop/GNOME

%description -n lib%name
Seahorse is a graphical interface for managing and using encryption keys. This package contains Seahorse libraries. Note: to use Seahorse, you should install seahorse package and/or Seahorse applet.

%package -n lib%name-devel
Summary: Seahorse development files
Group: Development/GNOME and GTK+
Requires: lib%name = %version-%release

%description -n lib%name-devel
This package contains files necessary to develop applications that use or
extend Seahorse encryption keys manager.

%package agent
Summary: Seahorse GPG/SSH Agent
Group: File tools
PreReq: lib%name = %version-%release
# TODO: When Bug #10595 is fixed, replace this with ssh-agent.
Requires: openssh-clients

%description agent
Seahorse is a graphical interface for managing and using encryption keys. 
Currently it supports PGP keys using for Gnu Privacy Guard. Its goal is to 
provide an easy to use Key Management Tool, along with an easy to use interface for encryption operations.

This package contains Seahorse Agent, a program that caches GPG/SSH passphrases
for the session. IMPORTANT NOTE: Seahorse Agent interacts with ssh-agent BUT is
not able to interact with gpg-agent, it appears as gpg-agent itself. Please
switch gpg-agent off if you intend to use seahorse-agent for GPG passphrases
caching.

%package -n nautilus-%name
Summary: Seahorse Nautilus plugin
Group: File tools
PreReq: nautilus2
PreReq: lib%name = %version-%release

%description -n nautilus-%name
Seahorse is a graphical interface for managing and using encryption keys. 
Currently it supports PGP keys using for Gnu Privacy Guard. Its goal is to 
provide an easy to use Key Management Tool, along with an easy to use interface for encryption operations.

This package contains seahorse Nautilus plugin.

%package -n gedit-plugins-%name
Summary: Seahorse gEdit plugin
Group: Editors
PreReq: gedit
PreReq: lib%name = %version-%release

%description -n gedit-plugins-%name
Seahorse is a graphical interface for managing and using encryption keys. 
Currently it supports PGP keys using for Gnu Privacy Guard. Its goal is to 
provide an easy to use Key Management Tool, along with an easy to use interface for encryption operations.

This package contains seahorse gEdit plugin.

%package -n gnome-applets-%name
Summary: Seahorse panel applet
Group: Graphical desktop/GNOME
PreReq: %name = %version-%release

%description -n gnome-applets-%name
Seahorse is a graphical interface for managing and using encryption keys. 
Currently it supports PGP keys using for Gnu Privacy Guard. Its goal is to 
provide an easy to use Key Management Tool, along with an easy to use interface for encryption operations.

This package contains Seahorse applet for the GNOME panel.

%if_enabled epiphany
%package -n epiphany-extension-seahorse
Group: Networking/WWW
Summary: Seahorse plugin for Epiphany
PreReq: %name = %version-%release
Requires: epiphany

%description -n epiphany-extension-seahorse
Seahorse is a graphical interface for managing and using encryption keys. 
Currently it supports PGP keys using for Gnu Privacy Guard. Its goal is to 
provide an easy to use Key Management Tool, along with an easy to use interface for encryption operations.

This package integrates Seahorse with the Epiphany web browser.
%endif


%prep
%setup -q
sed -i "s/update-mime-database/#update-mime-database/g" plugins/nautilus/Makefile.in
sed -i "s/update-mime-database/#update-mime-database/g" plugins/nautilus/Makefile.am


%build
#__autoreconf
%configure \
	%{subst_enable debug} \
	%{subst_with ldap} \
	%{subst_enable hkp} \
	--enable-keyserver \
	%{subst_enable nautilus} \
	--enable-agent \
	%{?_enable_gnome_keyring:--enable-gnome-keyring} \
	%{subst_enable sharing} \
	%{subst_enable dbus} \
%if_enabled epiphany
	   %{subst_enable epiphany} --with-gecko=firefox \
%endif
	%{subst_enable gedit} \
	--enable-applet \
	%{subst_enable libnotify} \
	%{subst_enable ssh} \
	--enable-tests \
	--disable-static \
	--disable-scrollkeeper \
	--disable-schemas-install \
	--disable-update-mime-database \

%make_build

%install
export GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL=1
%make_install install DESTDIR=%buildroot
unset GCONF_DISABLE_MAKEFILE_SCHEMA_INSTALL

mkdir -p %buildroot%_sysconfdir/X11/profile.d
install -m755 %SOURCE2 %buildroot%_sysconfdir/X11/profile.d/seahorse-agent.sh

%find_lang %name --with-gnome
%find_lang %name-applet --with-gnome

%post -n lib%name
%post_ldconfig

%postun -n lib%name
%postun_ldconfig

%post
%gconf2_install %name
%update_scrollkeeper
%update_desktopdb
%update_menus

%preun
if [ $1 = 0 ]; then
%gconf2_uninstall %name
fi

%postun
%clean_scrollkeeper
%clean_desktopdb
%clean_menus

%post agent
{
echo "Attention for those who use gpg-agent!"
echo "Seahorse-agent does not integrate with gpg-agent, but can act"
echo "as a gpg-agent itself. You should disable original gpg-agent"
echo "to avoid the mess (by default it is disabled)."
echo "(In short: make sure a line with 'use-agent'"
echo "in your ~/.gnupg/gpg.conf is commented out or absent)"
} || :

%post -n nautilus-%name
%update_mimedb

%postun -n nautilus-%name
%clean_mimedb

%post -n gedit-plugins-%name
%gconf2_install %name-gedit

%preun -n gedit-plugins-%name
if [ $1 = 0 ]; then
%gconf2_uninstall %name-gedit
fi

%files -n lib%name 
%_libdir/libcryptui.so.*
%_bindir/cryptui-test-keyset
%_bindir/cryptui-test-ui
%dir %_libdir/%name
%_libdir/%name/%name-ssh-askpass
%_libdir/%name/xloadimage

%files -f %name.lang
%_bindir/%name
%_bindir/%name-tool
%_bindir/%name-preferences
%attr(711,root,root) %_bindir/%name-daemon
%_man1dir/seahorse-daemon.*
%dir %_datadir/%name
%dir %_datadir/%name/glade
%_datadir/%name/glade/*.glade
%exclude %_datadir/%name/glade/%name-applet-*.glade
%_datadir/%name/glade/*.ui
%exclude %_datadir/%name/glade/seahorse-agent-cache.glade
%_datadir/dbus-1/services/*.service
%_iconsdir/hicolor/*/apps/%{name}*.*
%_pixmapsdir/%{name}*
%_desktopdir/*.desktop
#_datadir/control-center-2.0/capplets/*.desktop
%_man1dir/%name-tool.*
%config %gconf_schemasdir/seahorse.schemas
%doc AUTHORS ChangeLog COPYING COPYING-DOCS NEWS README THANKS TODO
# found by find_lang
#%%dir %gnomehelpdir/%name
#%%dir %_omfdir/%name
#%%_omfdir/%name/*
#%%gnomehelpdir/%name/*

%files -n lib%name-devel
%dir %_includedir/libcryptui
%_includedir/libcryptui/*.h
%_libdir/libcryptui.so
%_pkgconfigdir/cryptui-*.pc

%files agent
%_bindir/%name-agent
%_datadir/%name/glade/seahorse-agent-cache.glade
%_man1dir/seahorse-agent.*
%_sysconfdir/X11/profile.d/seahorse-agent.sh

%files -n nautilus-%name
#%nautilus_extdir/*
#%exclude %nautilus_extdir/*.la

%_datadir/mime/packages/*
%_libdir/nautilus/extensions-2.0/*
%exclude %_libdir/nautilus/extensions-2.0/*.la

%files -n gedit-plugins-%name
%gedit_pluginsdir/*
%exclude %gedit_pluginsdir/*.la
%config %gconf_schemasdir/%name-gedit.schemas

%files -n gnome-applets-%name -f %{name}-applet.lang
%_libdir/%name/%name-applet
%bonobo_serversdir/*.server
%_datadir/gnome-2.0/ui/*.xml
%_datadir/%name/glade/%name-applet-*.glade
# found by find_lang
#%%gnomehelpdir/%name-applet
#%%_omfdir/%name-applet

%if_enabled epiphany
%files -n epiphany-extension-seahorse
%_libdir/epiphany/*/extensions/*
%exclude %_libdir/epiphany/*/extensions/*.la
%endif

%changelog
* Tue Oct 21 2008 Andriy Stepanov <stanv@altlinux.ru> 2.22.1-alt1.qa1.M41.1
- Bug #17326

* Thu Apr 10 2008 Igor Vlasenko <viy@altlinux.ru> 2.22.1-alt1.qa1
- NMU (by repocop): the following fixes applied:
 * desktop-mime-entry for seahorse
 * update_menus for seahorse

* Tue Apr 08 2008 Alexey Shabalin <shaba@altlinux.ru> 2.22.1-alt1
- new version (2.22.1)

* Sun Mar 23 2008 Alexey Shabalin <shaba@altlinux.ru> 2.22.0-alt1.1
- build for Sisyphus

* Tue Mar 18 2008 Alexey Shabalin <shaba@altlinux.ru> 2.22.0-alt1
- new version (2.22.0)

* Mon Feb 04 2008 Alexey Shabalin <shaba@altlinux.ru> 2.20.3-alt1
- new version (2.20.3)
- add Packager
- update License
- fix files (for find_lang)

* Mon Dec 03 2007 Alexey Shabalin <shaba@altlinux.ru> 2.20.1-alt1
- new version (2.20.1)
- add package epiphany-extension-seahorse (build with firefox gecko), but disabled build default
- move found %%name.lang to main package

* Fri Jul 27 2007 Alexey Rusakov <ktirf@altlinux.org> 1.0.1-alt2
- added libSM-devel to buildreqs
- use macros from rpm-build-gnome

* Mon Apr 30 2007 Alexey Rusakov <ktirf@altlinux.org> 1.0.1-alt1
- new version (1.0.1)
- updated dependencies

* Wed Mar 14 2007 Alexey Rusakov <ktirf@altlinux.org> 1.0-alt1
- new version (1.0)
- enabled cryptui tests building

* Thu Mar 01 2007 Alexey Rusakov <ktirf@altlinux.org> 0.9.92-alt1
- new version 0.9.92 (with rpmrb script)

* Sat Feb 17 2007 Alexey Rusakov <ktirf@altlinux.org> 0.9.91-alt1
- new version 0.9.91 (with rpmrb script)

* Sat Jan 27 2007 Alexey Rusakov <ktirf@altlinux.org> 0.9.10-alt4
- Another replacement of %%_libexecdir with %%_libdir.

* Fri Jan 26 2007 Alexey Rusakov <ktirf@altlinux.org> 0.9.10-alt3
- %%_libdir instead of %%_libexecdir in libseahorse, to fix building on x86_64.

* Sun Jan 07 2007 Alexey Rusakov <ktirf@altlinux.org> 0.9.10-alt2
- added def_enable debug, enabled by default.
- minor update of buildreqs.
- fixed insufficient buildreqs and reqs (openssh-clients was missed out)

* Fri Jan 05 2007 Alexey Rusakov <ktirf@altlinux.org> 0.9.10-alt1
- new version (0.9.10)

* Tue Jan 02 2007 Alexey Rusakov <ktirf@altlinux.org> 0.9.9-alt2
- no more manual setup of seahorse-agent necessary, the appropriate script is
  installed to /etc/X11/profile.d/ directory.
- seahorse-agent replaces gpg-agent functionality, a warning about this is put
  into %%post script.

* Sun Dec 24 2006 Alexey Rusakov <ktirf@altlinux.org> 0.9.9-alt1
- new version (0.9.9)
- removed a patch that fixes linking, as it is not correct anymore (wonder why
  it still applies)
- files list updated
- enabled _unpackaged_files_terminate_build macro

* Thu Apr 20 2006 Alexey Rusakov <ktirf@altlinux.ru> 0.9.1-alt1
- new version

* Mon Apr 03 2006 Alexey Rusakov <ktirf@altlinux.ru> 0.9.0-alt1
- new version (0.9.0)
- removed Debian menu support
- updated dependencies
- introduced many switches, to control various Seahorse features.
- for backporters: older gedit is supported again.

* Tue Jan 17 2006 Alexey Rusakov <ktirf@altlinux.ru> 0.8-alt1
- new version

* Tue Oct 25 2005 Sir Raorn <raorn@altlinux.ru> 0.7.9-alt2
- Fix gedit requirements

* Sat Aug 27 2005 Sir Raorn <raorn@altlinux.ru> 0.7.9-alt1
- [0.7.9]

* Mon May 23 2005 Sir Raorn <raorn@altlinux.ru> 0.7.8-alt1
- [0.7.8]

* Tue Oct 19 2004 ALT QA Team Robot <qa-robot@altlinux.org> 0.6.3-alt1.1
- Updated build dependencies (libgpgme-compat-devel).

* Wed May 12 2004 Sir Raorn <raorn@altlinux.ru> 0.6.3-alt1
- [0.6.3]

* Tue Jun 12 2001 AEN <aen@logic.ru> 0.5.0-alt1
- 0.5.0
- russian po-file fixed

* Tue Jan 30 2001 Dmitry V. Levin <ldv@fandra.org> 0.4.9-ipl1mdk
- RE adaptions.

* Mon Jan 29 2001 Lenny Cartier <lenny@mandrakesoft.com> 0.4.9-1mdk
- updated to 0.4.9

* Fri Sep 15 2000 Lenny Cartier <lenny@mandrakesoft.com> 0.3.6-2mdk
- macros
- bm
- menu

* Mon Apr 03 2000 Lenny Cartier <lenny@mandrakesoft.com> 0.3.6-1mdk
- fix group
- used srpm provided by Vincent Danen <vdanen@linux-mandrake.com>

* Sun Mar 19 2000 Vincent Danen <vdanen@linux-mandrake.com>
- 0.3.6
- specfile changes for spec-helper

* Fri Feb 11 2000 Vincent Danen <vdanen@linux-mandrake.com>
- initial specfile
- bzip sources
- bzip manpages




